# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/zh_CN/__init__.py

lorem_word_connector_zh_cn <- ""
lorem_word_list_zh_cn <- c(
  "\u4e00\u4e2a",
  "\u6211\u4eec",
  "\u65f6\u95f4",
  "\u4e2d\u56fd",
  "\u53ef\u4ee5",
  "\u516c\u53f8",
  "\u6ca1\u6709",
  "\u4fe1\u606f",
  "\u4e0b\u8f7d",
  "\u8f6f\u4ef6",
  "\u6ce8\u518c",
  "\u81ea\u5df1",
  "\u4ea7\u54c1",
  "\u5de5\u4f5c",
  "\u8bba\u575b",
  "\u4f01\u4e1a",
  "\u8fd9\u4e2a",
  "\u4ed6\u4eec",
  "\u7ba1\u7406",
  "\u5df2\u7ecf",
  "\u95ee\u9898",
  "\u5185\u5bb9",
  "\u4f7f\u7528",
  "\u8fdb\u884c",
  "\u5e02\u573a",
  "\u670d\u52a1",
  "\u5982\u679c",
  "\u7cfb\u7edf",
  "\u6280\u672f",
  "\u53d1\u5c55",
  "\u73b0\u5728",
  "\u4f5c\u8005",
  "\u5c31\u662f",
  "\u7f51\u7edc",
  "\u63d0\u4f9b",
  "\u76f8\u5173",
  "\u6211\u7684",
  "\u6587\u7ae0",
  "\u65b9\u5f0f",
  "\u7535\u8bdd",
  "\u53d1\u8868",
  "\u6240\u6709",
  "\u65f6\u5019",
  "\u56e0\u4e3a",
  "\u5317\u4eac",
  "\u6709\u9650",
  "\u516c\u53f8",
  "\u4ec0\u4e48",
  "\u8fd8\u662f",
  "\u5f00\u59cb",
  "\u672c\u7ad9",
  "\u53d1\u5e03",
  "\u81ea\u5df1",
  "\u652f\u6301",
  "\u5728\u7ebf",
  "\u56fd\u5bb6",
  "\u751f\u6d3b",
  "\u8054\u7cfb",
  "\u79ef\u5206",
  "\u4e3b\u9898",
  "\u6240\u4ee5",
  "\u4e0d\u80fd",
  "\u7684\u4eba",
  "\u4e0a\u6d77",
  "\u4e2d\u5fc3",
  "\u4e16\u754c",
  "\u6e38\u620f",
  "\u9700\u8981",
  "\u4ef7\u683c",
  "\u7528\u6237",
  "\u901a\u8fc7",
  "\u8981\u6c42",
  "\u4e0d\u662f",
  "\u514d\u8d39",
  "\u4e2a\u4eba",
  "\u4f46\u662f",
  "\u5730\u5740",
  "\u7f51\u7ad9",
  "\u60c5\u51b5",
  "\u6700\u540e",
  "\u8bbe\u8ba1",
  "\u540c\u65f6",
  "\u8fd9\u4e9b",
  "\u6d3b\u52a8",
  "\u624b\u673a",
  "\u63a8\u8350",
  "\u4e00\u4e9b",
  "\u4e3b\u8981",
  "\u5927\u5bb6",
  "\u53d1\u73b0",
  "\u76ee\u524d",
  "\u6587\u4ef6",
  "\u4f60\u7684",
  "\u4e0d\u8fc7",
  "\u8bc4\u8bba",
  "\u751f\u4ea7",
  "\u7f8e\u56fd",
  "\u56fe\u7247",
  "\u7ecf\u6d4e",
  "\u529f\u80fd",
  "\u56fd\u9645",
  "\u7684\u662f",
  "\u9009\u62e9",
  "\u5176\u4ed6",
  "\u8fd9\u6837",
  "\u4f1a\u5458",
  "\u73af\u5883",
  "\u6765\u81ea",
  "\u65e5\u671f",
  "\u6210\u4e3a",
  "\u4ed6\u7684",
  "\u6700\u65b0",
  "\u4e13\u4e1a",
  "\u4e00\u4e0b",
  "\u4eba\u5458",
  "\u4efb\u4f55",
  "\u6559\u80b2",
  "\u8d44\u6599",
  "\u72b6\u6001",
  "\u90fd\u662f",
  "\u70b9\u51fb",
  "\u4e3a\u4e86",
  "\u4e0d\u4f1a",
  "\u51fa\u73b0",
  "\u77e5\u9053",
  "\u793e\u4f1a",
  "\u540d\u79f0",
  "\u800c\u4e14",
  "\u4ecb\u7ecd",
  "\u97f3\u4e50",
  "\u7b49\u7ea7",
  "\u53ef\u80fd",
  "\u8fd9\u79cd",
  "\u5efa\u8bbe",
  "\u670b\u53cb",
  "\u867d\u7136",
  "\u7535\u5b50",
  "\u8d44\u6e90",
  "\u770b\u5230",
  "\u7cbe\u534e",
  "\u7535\u5f71",
  "\u5982\u4f55",
  "\u65b0\u95fb",
  "\u9605\u8bfb",
  "\u5b89\u5168",
  "\u5168\u56fd",
  "\u53ea\u6709",
  "\u56de\u590d",
  "\u5927\u5b66",
  "\u5b66\u751f",
  "\u5b66\u4e60",
  "\u5173\u4e8e",
  "\u9879\u76ee",
  "\u4e0d\u540c",
  "\u4ee5\u53ca",
  "\u6709\u5173",
  "\u90a3\u4e48",
  "\u5f00\u53d1",
  "\u8fd8\u6709",
  "\u53ea\u662f",
  "\u975e\u5e38",
  "\u7814\u7a76",
  "\u5e7f\u544a",
  "\u9996\u9875",
  "\u65b9\u6cd5",
  "\u5e0c\u671b",
  "\u5730\u65b9",
  "\u4e5f\u662f",
  "\u5355\u4f4d",
  "\u600e\u4e48",
  "\u5e94\u8be5",
  "\u4eca\u5929",
  "\u4ee5\u4e0a",
  "\u66f4\u65b0",
  "\u5e16\u5b50",
  "\u663e\u793a",
  "\u80fd\u529b",
  "\u7535\u8111",
  "\u8bb0\u8005",
  "\u67e5\u770b",
  "\u4f4d\u7f6e",
  "\u4e0d\u8981",
  "\u7531\u4e8e",
  "\u65e0\u6cd5",
  "\u8be6\u7ec6",
  "\u6295\u8d44",
  "\u662f\u4e00",
  "\u4e00\u822c",
  "\u8fdb\u5165",
  "\u53d1\u751f",
  "\u8fd9\u91cc",
  "\u611f\u89c9",
  "\u66f4\u591a",
  "\u4f60\u4eec",
  "\u7684\u8bdd",
  "\u8d77\u6765",
  "\u6807\u51c6",
  "\u4e00\u6837",
  "\u8ba4\u4e3a",
  "\u5973\u4eba",
  "\u90a3\u4e2a",
  "\u8bbe\u5907",
  "\u641c\u7d22",
  "\u4e4b\u540e",
  "\u7136\u540e",
  "\u5b66\u6821",
  "\u9500\u552e",
  "\u7ec4\u7ec7",
  "\u8bf4\u660e",
  "\u63d0\u9ad8",
  "\u4e3a\u4ec0",
  "\u4f5c\u54c1",
  "\u6216\u8005",
  "\u559c\u6b22",
  "\u4e1c\u897f",
  "\u65b9\u9762",
  "\u7b80\u4ecb",
  "\u5fc5\u987b",
  "\u7ecf\u8425",
  "\u79d1\u6280",
  "\u4f5c\u4e3a",
  "\u5176\u4e2d",
  "\u8fd0\u884c",
  "\u5de5\u7a0b",
  "\u89e3\u51b3",
  "\u64cd\u4f5c",
  "\u7ecf\u9a8c",
  "\u5730\u533a",
  "\u91cd\u8981",
  "\u76f4\u63a5",
  "\u767b\u5f55",
  "\u5408\u4f5c",
  "\u7ed3\u679c",
  "\u5f71\u54cd",
  "\u8fd9\u662f",
  "\u884c\u4e1a",
  "\u5bf9\u4e8e",
  "\u8868\u793a",
  "\u7a0b\u5e8f",
  "\u5305\u62ec",
  "\u7559\u8a00",
  "\u89c4\u5b9a",
  "\u5904\u7406",
  "\u7537\u4eba",
  "\u5404\u79cd",
  "\u90e8\u95e8",
  "\u6570\u636e",
  "\u5177\u6709",
  "\u5546\u54c1",
  "\u7cfb\u5217",
  "\u5927\u5c0f",
  "\u56e0\u6b64",
  "\u5173\u7cfb",
  "\u53ef\u662f",
  "\u6bd4\u8f83",
  "\u6587\u5316",
  "\u4e00\u76f4",
  "\u6cd5\u5f8b",
  "\u8fd9\u4e48",
  "\u60a8\u7684",
  "\u57ce\u5e02",
  "\u5206\u6790",
  "\u57fa\u672c",
  "\u6700\u5927",
  "\u7c7b\u522b",
  "\u4e24\u4e2a",
  "\u65e5\u672c",
  "\u5f97\u5230",
  "\u4e00\u6b21",
  "\u7ee7\u7eed",
  "\u6210\u529f",
  "\u5979\u7684",
  "\u8d23\u4efb",
  "\u6df1\u5733",
  "\u4e1a\u52a1",
  "\u6b22\u8fce",
  "\u52a0\u5165",
  "\u80fd\u591f",
  "\u89c9\u5f97",
  "\u90e8\u5206",
  "\u4e2d\u6587",
  "\u6839\u636e",
  "\u4eba\u6c11",
  "\u653f\u5e9c",
  "\u63a7\u5236",
  "\u5176\u5b9e",
  "\u4e4b\u95f4",
  "\u4e00\u79cd",
  "\u5a01\u671b",
  "\u5b9e\u73b0",
  "\u8bed\u8a00",
  "\u51fa\u6765",
  "\u8c22\u8c22",
  "\u793e\u533a",
  "\u54c1\u724c",
  "\u662f\u5426",
  "\u5de5\u5177",
  "\u5b8c\u5168",
  "\u51b3\u5b9a",
  "\u5f88\u591a",
  "\u7f51\u4e0a",
  "\u4e8b\u60c5",
  "\u4eca\u5e74",
  "\u56fd\u5185",
  "\u4ee5\u540e",
  "\u5236\u4f5c",
  "\u6d4f\u89c8",
  "\u8fc7\u7a0b",
  "\u5b8c\u6210",
  "\u7c7b\u578b",
  "\u6765\u6e90",
  "\u8d28\u91cf",
  "\u6709\u4e9b",
  "\u4e00\u8d77",
  "\u5f53\u7136",
  "\u6c7d\u8f66",
  "\u4e00\u70b9",
  "\u5e2e\u52a9",
  "\u589e\u52a0",
  "\u5386\u53f2",
  "\u4ee5\u4e0b",
  "\u4e0d\u65ad",
  "\u5e94\u7528",
  "\u90a3\u4e9b",
  "\u5bc6\u7801",
  "\u8ba1\u5212",
  "\u5982\u6b64",
  "\u6b21\u6570",
  "\u5230\u4e86",
  "\u62e5\u6709",
  "\u5b69\u5b50",
  "\u539f\u56e0",
  "\u53c2\u52a0",
  "\u53ea\u8981",
  "\u62a5\u544a",
  "\u5f53\u524d",
  "\u5ba2\u6237",
  "\u6b63\u5728",
  "\u6ce8\u610f",
  "\u6807\u9898",
  "\u7a7a\u95f4",
  "\u4e00\u5b9a",
  "\u4e00\u5207",
  "\u7279\u522b",
  "\u5168\u90e8",
  "\u51c6\u5907"
)

#' Lorem provider Chinese (China)
#'
#' Methods for Lorem Ipsum generation.
#' Lorem Ipsum is a placeholder text commonly used to demonstrate the visual
#' form of a document or a typeface without relying on meaningful content.
#' @family zh
#' @family CN
#' @export
#' @examples
#' x <- LoremProvider_zh_CN$new()
#' x$word()
#' x$words(3)
#' x$words(6)
#' x$sentence()
#' x$paragraph()
#' x$paragraphs(3)
#' cat(x$paragraphs(6), sep = "\n")
#' x$text(19)
#' x <- LoremProvider_zh_CN$new(word_connector = " --- ")
#' x$paragraph(4)
LoremProvider_zh_CN <- R6::R6Class(
  inherit = LoremProvider,
  "LoremProvider_zh_CN",
  private = list(
    locale_ = "zh_CN",
    word_list = lorem_word_list_zh_cn,
    word_connector = lorem_word_connector_zh_cn
  )
)
